@@ -24,4 +24,10 @@ class UnknownError(Exception):
     pass
 
 class InvalidPPBool(Exception):
+    pass
+
+class InvalidFormat(Exception):
+    pass
+
+class FFmpegError(Exception):
     pass
\ No newline at end of file
